/***************************************************************************
 * Related object autocomplete
 ***************************************************************************/
.related-object-options,
.related-object-selected {
  font-size: 11px;
}
.related-object-options img,
.related-object-selected img {
  width: 20px;
  height: 20px;
  border-radius: 10px;
  vertical-align: top;
}
.related-object-options span,
.related-object-selected span {
  line-height: 20px;
  vertical-align: top;
}
.related-object-options .title,
.related-object-selected .title {
  display: inline-block;
  min-width: 20em;
  font-size: 11px;
}
.related-object-options .description,
.related-object-selected .description {
  display: inline-block;
  font-size: 9.9px;
  padding: 0;
}
.related-object-selector {
  vertical-align: middle;
}
.related-object-selector .related-object-selected {
  background: var(--ink-p-input-bg);
  border: var(--ink-g-border-input);
  border-radius: var(--ink-g-border-radius-input);
  margin: 0.5em 0 0 0;
  max-height: 20em;
  min-height: 3em;
  overflow-y: auto;
  padding: 0;
}
.related-object-selector ul.related-object-selected {
  list-style: none;
}
.related-object-selector ul.related-object-selected li {
  cursor: default;
  padding: 5px 8px;
  vertical-align: middle;
}
.related-object-selector ul.related-object-selected li div {
  display: inline-block;
}
.related-object-selector ul.related-object-selected .remove-item {
  cursor: pointer;
  float: right;
  padding-top: 2px;
  padding-bottom: 2px;
}
.related-object-selector ul.related-object-selected .remove-item:hover {
  color: var(--ink-p-fg);
}
.related-object-selector ul.related-object-selected .remove-item:not(:hover) {
  color: var(--ink-p-fg-weak);
}
.related-object-selector table.related-object-selected {
  padding: var(--ink-u-spacing-xs);
  width: 100%;
}
.related-object-selector table.related-object-selected td:last-child {
  width: var(--ink-u-icon-std);
}
.related-object-selector table.related-object-selected .remove-item:hover {
  color: var(--ink-p-fg);
}
.related-object-selector table.related-object-selected .remove-item:not(:hover) {
  color: var(--ink-p-fg-weak);
}
.related-object-selector .selectize-control .selectize-input {
  background: var(--ink-p-input-bg);
  border: var(--ink-g-border-input);
  box-shadow: none;
  font-size: 11px;
  padding: 4px;
}
.related-object-selector .selectize-control .selectize-input::after {
  right: 10px;
}
.related-object-selector .selectize-control .selectize-input.selectize-input.input-active {
  background: var(--ink-p-input-bg);
}
.related-object-selector .selectize-control .selectize-input.selectize-input.dropdown-active:before {
  background: none;
}
.related-object-selector .selectize-control .selectize-input input {
  color: var(--ink-p-input-fg) !important;
  width: 100% !important;
  /* To overwrite the measureString() return value,
        which seems to  be broken in selectize-0.12.1 */
}
.selectize-dropdown {
  border-color: var(--ink-p-input-border-color) !important;
  background: var(--ink-p-input-bg);
  color: var(--ink-p-input-fg);
}
.selectize-dropdown .active {
  background: var(--ink-p-input-selection-bg);
  color: var(--ink-p-input-fg);
}
/*# sourceMappingURL=related-object-selector.css.map */